==> particle_setup-0.3.1.tar.gz: CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.3.1](https://github.com/kirkeaton/particle_setup/compare/0.3.0...0.3.1) (2020-10-03)


### Bug Fixes

- Remove duplicate JsonKey `rssi` from wifiSignalStrength ([387461f](https://github.com/kirkeaton/particle_setup/commit/387461fc4bbcec617f4e6f4ff03ec0a461a0b808))


### Chores

- Add .circleci/config.yml ([b69ba48](https://github.com/kirkeaton/particle_setup/commit/b69ba48ac8480a6c738340d52ec7d42846b50c37))
- add documentation for api, commands, responses and utils ([188d16f](https://github.com/kirkeaton/particle_setup/commit/188d16fa12be5e7b6b55129855540d4ffd23ebeb))
- format code using dartfmt ([02c3e39](https://github.com/kirkeaton/particle_setup/commit/02c3e39b381b123e78fcea4aa70bbf4835bc5944))
- Remove author field from pubspec.yaml ([f8287af](https://github.com/kirkeaton/particle_setup/commit/f8287af807ef63afec10a3960c64d504007cb879))
- remove Flutter dependencies ([6ab1663](https://github.com/kirkeaton/particle_setup/commit/6ab1663e9aeb77387f306021d3cb2a18ea20ef1e))


### [0.3.0](https://github.com/kirkeaton/particle_setup/compare/0.2.0...0.3.0) (2020-04-22)


### Features

- add `rssi` field to Scan class ([feaff60](https://github.com/kirkeaton/particle_setup/commit/feaff605c21dc232aed8302b02468306ea4485d5))


### [0.2.0](https://github.com/kirkeaton/particle_setup/compare/0.1.0...0.2.0) (2020-02-12)


### Features

- add `wifiSignalStrength` to Scan class ([ace22ae](https://github.com/kirkeaton/particle_setup/commit/ace22aef87b8a4b92aba232f6598bef0dd114f50))


### [0.1.0](https://github.com/kirkeaton/particle_setup/releases/tag/0.1.0) (2019-11-18)

- Initial release

==> particle_setup-0.4.0.tar.gz: CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [0.4.0](https://github.com/kirkeaton/particle_setup/compare/0.3.1...0.4.0) (2021-05-03)

### Chores

- Re-add build_runner and build_test ([f4237d1](https://github.com/kirkeaton/particle_setup/commit/f4237d1722f0a9303f0aa291a4a2ed56adaf2c37))
- Remove CircleCI badge ([9c4a66b](https://github.com/kirkeaton/particle_setup/commit/9c4a66b8dbfb229a413cef87e241646a04803da8))
- Require Dart 2.10.0 and move to GitHub actions ([cbbd404](https://github.com/kirkeaton/particle_setup/commit/cbbd40412f8b2565710b0ead07b6a7b591b1ca9d))

## [0.3.1](https://github.com/kirkeaton/particle_setup/compare/0.3.0...0.3.1) (2020-10-03)

### Bug Fixes

- Remove duplicate JsonKey `rssi` from wifiSignalStrength ([387461f](https://github.com/kirkeaton/particle_setup/commit/387461fc4bbcec617f4e6f4ff03ec0a461a0b808))

### Chores

- Add .circleci/config.yml ([b69ba48](https://github.com/kirkeaton/particle_setup/commit/b69ba48ac8480a6c738340d52ec7d42846b50c37))
- add documentation for api, commands, responses and utils ([188d16f](https://github.com/kirkeaton/particle_setup/commit/188d16fa12be5e7b6b55129855540d4ffd23ebeb))
- format code using dartfmt ([02c3e39](https://github.com/kirkeaton/particle_setup/commit/02c3e39b381b123e78fcea4aa70bbf4835bc5944))
- Remove author field from pubspec.yaml ([f8287af](https://github.com/kirkeaton/particle_setup/commit/f8287af807ef63afec10a3960c64d504007cb879))
- remove Flutter dependencies ([6ab1663](https://github.com/kirkeaton/particle_setup/commit/6ab1663e9aeb77387f306021d3cb2a18ea20ef1e))

## [0.3.0](https://github.com/kirkeaton/particle_setup/compare/0.2.0...0.3.0) (2020-04-22)

### Features

- add `rssi` field to Scan class ([feaff60](https://github.com/kirkeaton/particle_setup/commit/feaff605c21dc232aed8302b02468306ea4485d5))

## [0.2.0](https://github.com/kirkeaton/particle_setup/compare/0.1.0...0.2.0) (2020-02-12)

### Features

- add `wifiSignalStrength` to Scan class ([ace22ae](https://github.com/kirkeaton/particle_setup/commit/ace22aef87b8a4b92aba232f6598bef0dd114f50))

## [0.1.0](https://github.com/kirkeaton/particle_setup/releases/tag/0.1.0) (2019-11-18)

- Initial release
